<?php
if (session_status() === PHP_SESSION_NONE) {
    session_start();
}

if (!isset($_SESSION['email'])) {
    header('Location: /?action=login');
    exit();
}

?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>Dashboard - Please Help Programmers</title>
    <link rel="shortcut icon" href="/assets/img/favicon.png" type="image/png">
    <link rel="stylesheet" href="/assets/css/bootstrap.min.css">
    <link rel="stylesheet" href="/assets/css/all.min.css">
    <link rel="stylesheet" href="/assets/css/styles.css">
    <link rel="stylesheet" href="/assets/css/dashboard.css">
</head>
<body>
    <div class="nav-bar" style="padding-bottom: 0px;">
        <button onclick="window.location.href='/?action=logout'" class="btn">
            <i class="fas fa-sign-out-alt"></i> Logout
        </button>
    </div>
    <div class="hero-section">
        <h1>Welcome, <?= htmlspecialchars($_SESSION['username']); ?> !</h1>
        <p>Discover the secrets of PHP development and become a better developer.</p>
    </div>
    <div class="container tips-section">
    <h2 class="mb-4">Tips for PHP Developers</h2>
    <div class="row">
        
        <div class="col-md-6 tip-card">
            <div class="card">
                <div class="card-body">
                    <h5 class="card-title"><i class="fas fa-key"></i> Use <code>mt_rand()</code> to generate robust secrets</h5>
                    <p class="card-text">Why use complex functions for security when <code>mt_rand()</code> is there? It's fast and simple, perfect for generating reset tokens.</p>
                </div>
            </div>
        </div>
        <div class="col-md-6 tip-card">
            <div class="card">
                <div class="card-body">
                    <h5 class="card-title"><i class="fas fa-user-lock"></i> Store passwords in plain text</h5>
                    <p class="card-text">Why use <code>password_hash()</code> when you can read passwords directly from the database? A real time saver for retrieval.</p>
                </div>
            </div>
        </div>
        <div class="col-md-6 tip-card">
            <div class="card">
                <div class="card-body">
                    <h5 class="card-title"><i class="fas fa-lock-open"></i> Disable input validation</h5>
                    <p class="card-text">Why complicate your life with <code>filter_input()</code> and <code>htmlspecialchars()</code> ? Trust the user to send safe data.</p>
                </div>
            </div>
        </div>
        <div class="col-md-6 tip-card">
            <div class="card">
                <div class="card-body">
                    <h5 class="card-title"><i class="fas fa-cogs"></i> Enable <code>register_globals</code> to simplify your life</h5>
                    <p class="card-text">Simplify your code by enabling <code>register_globals</code>. No need for <code>$_GET</code> or <code>$_POST</code>, everything is accessible directly!</p>
                </div>
            </div>
        </div>
    </div>
</div>
<?php
/* Include a special card */
if ($_SESSION['username'] === 'admin') {
    if (isset($_GET["special_card"])) {
        $card = htmlspecialchars($_GET["special_card"]);
        if (file_exists($card) && substr($card, -5) == '.html') {
            include($card);
        } else {
            echo "<div class='alert alert-danger text-center'>File not found or not an HTML file.</div>";
        }
    }
}
?>
    <script src="/assets/js/jquery.min.js"></script>
    <script src="/assets/js/bootstrap.min.js"></script>
</body>
</html>
